# Credits

## Included Projects

Project dependencies:

- [prism](http://prismjs.com/)
- [vanilla-js](http://vanilla-js.com/)

Project documentation:

- [MkDocs](http://www.mkdocs.org/)

Tools used in rendering this package:

- [Cookiecutter]
- [cookiecutter-djangopackage]

  [Cookiecutter]: https://github.com/audreyr/cookiecutter
  [cookiecutter-djangopackage]: https://github.com/pydanny/cookiecutter-djangopackage

{!AUTHORS.md!}
